==> support-api-1.2.2.34-20230817.034258-1-sources.jar: com/elitesland/support/provider/pri/service/param/ItmPriPricePagingRpcDtoParam.java <==
package com.elitesland.support.provider.pri.service.param;

import com.elitescloud.cloudt.common.base.param.AbstractOrderQueryParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.time.LocalDateTime;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@ApiModel("商品价格查询条件")
public class ItmPriPricePagingRpcDtoParam extends AbstractOrderQueryParam implements Serializable {

    private static final long serialVersionUID = -4338427891182297120L;

    @ApiModelProperty("商品ID列表")
    private Long itemId;

    @ApiModelProperty("商品编号列表")
    private String itemCode;

    @ApiModelProperty(value = "销售组织")
    private String saleOrg;

    @ApiModelProperty(value = "价格类型 [UDC]yst-support: PRICE_TYPE")
    private String priceType;

    @ApiModelProperty(value = "渠道类型 [UDC]yst-support: CHANNEL_TYPE")
    private String channelType;

    @ApiModelProperty(value = "分销渠道")
    private String saleChannel;

    @ApiModelProperty(value = "客户编码")
    private String custKey;

    @ApiModelProperty(value = "客户区域 [UDC]yst-support: REGION")
    private String region;

//    @ApiModelProperty(value = "商品类型 [UDC]yst-support: ITEM_TYPE2")
//    private String itemType2;

    @ApiModelProperty(value = "商品类型3 [UDC]yst-supp: ITEM_TYPE3")
    private String itemType3;

    @ApiModelProperty(value = "整车定位")
    private String itemPosit;

    @ApiModelProperty(value = "包装方式 [UDC]yst-supp: PACK_DEMAND")
    private String packDemand;

    @ApiModelProperty(value = "商品分组 [UDC]yst-supp: ITEM_GROUP")
    private String itemGroup;

    @ApiModelProperty(value = "生产基地 [UDC]yst-support: ORIGIN")
    private String origin;

    @ApiModelProperty(value = "发货基地")
    private String desCode;

    @ApiModelProperty("生效时间点，用于查询指定生效时间点的数据")
    private LocalDateTime validTime;

    @ApiModelProperty("生效时间，时间区间开始，大于等于")
    private LocalDateTime effectiveDatetime;

    @ApiModelProperty("失效时间，时间区间结束，小于等于")
    private LocalDateTime expiryDatetime;

    @ApiModelProperty(value = "价格状态")
    private String priceStatus;

}

==> support-api-1.2.2.59-20230831.023306-1-sources.jar: com/elitesland/support/provider/pri/service/param/ItmPriPricePagingRpcDtoParam.java <==
package com.elitesland.support.provider.pri.service.param;

import com.elitescloud.cloudt.common.base.param.AbstractOrderQueryParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.time.LocalDateTime;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@ApiModel("商品价格查询条件")
public class ItmPriPricePagingRpcDtoParam extends AbstractOrderQueryParam implements Serializable {

    private static final long serialVersionUID = -4338427891182297120L;

    @ApiModelProperty("商品ID列表")
    private Long itemId;

    @ApiModelProperty("商品编号列表")
    private String itemCode;

    @ApiModelProperty(value = "销售组织")
    private String saleOrg;

    @ApiModelProperty(value = "价格类型 [UDC]yst-support: PRICE_TYPE")
    private String priceType;

    @ApiModelProperty(value = "渠道类型 [UDC]yst-support: CHANNEL_TYPE")
    private String channelType;

    @ApiModelProperty(value = "分销渠道")
    private String saleChannel;

    @ApiModelProperty(value = "客户编码")
    private String custKey;

    @ApiModelProperty(value = "客户区域 [UDC]yst-support: REGION")
    private String region;

//    @ApiModelProperty(value = "商品类型 [UDC]yst-support: ITEM_TYPE2")
//    private String itemType2;

    @ApiModelProperty(value = "商品类型3 [UDC]yst-supp: ITEM_TYPE3")
    private String itemType3;

    @ApiModelProperty(value = "整车定位")
    private String itemPosit;

    @ApiModelProperty(value = "包装方式 [UDC]yst-supp: PACK_DEMAND")
    private String packDemand;

    @ApiModelProperty(value = "商品分组 [UDC]yst-supp: ITEM_GROUP")
    private String itemGroup;

    @ApiModelProperty(value = "生产基地 [UDC]yst-support: ORIGIN")
    private String origin;

    @ApiModelProperty(value = "发货基地")
    private String desCode;

    @ApiModelProperty("生效时间点，用于查询指定生效时间点的数据")
    private LocalDateTime validTime;

    @ApiModelProperty("生效时间，时间区间开始，大于等于")
    private LocalDateTime effectiveDatetime;

    @ApiModelProperty("失效时间，时间区间结束，小于等于")
    private LocalDateTime expiryDatetime;

    @ApiModelProperty(value = "价格状态")
    private String priceStatus;

    @ApiModelProperty(value = "单位")
    private String uom;

    @ApiModelProperty(value = "货币码")
    private String currCode;

}
